
import Mock from 'mockjs'

const tokens = {
  admin: {
    token: 'admin-token'
  },
  assistant: {
    token: 'assistant-token'
  },
  runner: {
    token: 'runner-token'
  },
  shoper: {
    token: 'shoper-token'
  }
}

const users = {
  'admin-token': {
    roles: ['admin'],
    introduction: 'I am a super administrator',
    avatar: 'https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif',
    name: 'Super Admin'
  },
  'assistant-token': {
    roles: ['assistant'],
    introduction: 'I am an assistant',
    avatar: 'https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif',
    name: 'Normal assistant'
  },
  'runner-token': {
    roles: ['runner'],
    introduction: 'I am an runner',
    avatar: 'https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif',
    name: 'Normal runner'
  },
  'shoper-token': {
    roles: ['shoper'],
    introduction: 'I am an shoper',
    avatar: 'https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif',
    name: 'Normal shoper'
  }
}

const List = []
const count = 10

const baseContent = '<p>I am testing data, I am testing data.</p><p><img src="https://wpimg.wallstcn.com/4c69009c-0fd4-4153-b112-6cb53d1cf943"></p>'
const image_uri = 'https://wpimg.wallstcn.com/e4558086-631c-425c-9430-56ffb46e70b3'

for (let i = 0; i < count; i++) {
  List.push(Mock.mock({
    uid: '@increment',
    create_time: +Mock.Random.date('T'),
    nickname: '@first',
    // reviewer: '@first',
    // title: '@title(5, 10)',
    openid: '@sentence(12,12)',
    comefromperson: '@title(1, 4)',
    buyvalue:'@integer(1,100)',
    buywill:'@integer(1,100)',
    // content_short: 'mock data',
    // content: baseContent,
    // forecast: '@float(0, 100, 2, 2)',
    // importance: '@integer(1, 3)',
    'type|1': ['CN', 'US', 'JP', 'EU'],
    'status|1': ['published', 'draft'],
    // display_time: '@datetime',
    // comment_disabled: true,
    son_of_adv: '@integer(300, 5000)',//下线
    souceof:'@integer(300, 5000)',//源自
    image_uri,
    'roles|1': ['admin', 'assistant', 'shoper', 'runner'],
    platforms: ['a-platform']//哪个平台
  }))
}

export default [
  // user login
  {
    url: '/yp/user/login',
    type: 'post',
    response: config => {
      const { username } = config.body
      const token = tokens[username]

      // mock error
      if (!token) {
        return {
          code: 60204,
          message: 'Account and password are incorrect.'
        }
      }

      return {
        code: 20000,
        data: token
      }
    }
  },

  // get user info
  {
    url: '/yp/user/info\.*',
    type: 'get',
    response: config => {
      const { token } = config.query
      const info = users[token]

      // mock error
      if (!info) {
        return {
          code: 50008,
          message: 'Login failed, unable to get user details.'
        }
      }

      return {
        code: 20000,
        data: info
      }
    }
  },

  // user logout
  {
    url: '/yp/user/logout',
    type: 'post',
    response: _ => {
      return {
        code: 20000,
        data: 'success'
      }
    }
  },
  // user create
  {
    url: '/yp/user/create',
    type: 'post',
    response: _ => {
      return {
        code: 20000,
        data: 'success'
      }
    }
  },
  // user update
  {
    url: '/yp/user/update',
    type: 'post',
    response: _ => {
      return {
        code: 20000,
        data: 'success'
      }
    }
  },
  // user del
  {
    url: '/yp/user/del',
    type: 'post',
    response: _ => {
      return {
        code: 20000,
        data: 'success'
      }
    }
  },
  // user list
  {
    url: '/yp/user/list',
    type: 'get',
    response: config => {
      const {
        importance,
        type,
        title,
        page = 1,
        limit = 20,
        sort
      } = config.query

      let mockList = List.filter(item => {
        if (importance && item.importance !== +importance) return false
        if (type && item.type !== type) return false
        if (title && item.title.indexOf(title) < 0) return false
        return true
      })

      if (sort === '-id') {
        mockList = mockList.reverse()
      }

      const pageList = mockList.filter((item, index) => index < limit * page && index >= limit * (page - 1))

      return {
        code: 20000,
        data: {
          total: mockList.length,
          items: pageList
        }
      }
    }
  }
]
